@@ -1,21 +1,50 @@
 /*
- * Copyright (C) 1998-2001, 2004, 2006-2009, 2012, 2014-2016  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
-/* $Id: time.h,v 1.35 2009/01/05 23:47:54 tbox Exp $ */
 
 #ifndef ISC_TIME_H
 #define ISC_TIME_H 1
 
+#include <errno.h>
+#include <inttypes.h>
+#include <stdbool.h>
 #include <windows.h>
 
 #include <isc/lang.h>
 #include <isc/types.h>
 
+/***
+ *** POSIX Shims
+ ***/
+
+inline struct tm *
+gmtime_r(const time_t *clock, struct tm *result) {
+	errno_t ret = gmtime_s(result, clock);
+	if (ret != 0) {
+		errno = ret;
+		return (NULL);
+	}
+	return (result);
+}
+
+inline struct tm *
+localtime_r(const time_t *clock, struct tm *result) {
+	errno_t ret = localtime_s(result, clock);
+	if (ret != 0) {
+		errno = ret;
+		return (NULL);
+	}
+	return (result);
+}
+
 /***
  *** Intervals
  ***/
@@ -27,7 +56,7 @@
  * The contents are exposed only to allow callers to avoid dynamic allocation.
  */
 struct isc_interval {
-	isc_int64_t interval;
+	int64_t interval;
 };
 
 LIBISC_EXTERNAL_DATA extern const isc_interval_t * const isc_interval_zero;
@@ -55,10 +84,10 @@ isc_interval_set(isc_interval_t *i,
  *	nanoseconds < 1000000000.
  */
 
-isc_boolean_t
+bool
 isc_interval_iszero(const isc_interval_t *i);
 /*
- * Returns ISC_TRUE iff. 'i' is the zero interval.
+ * Returns true iff. 'i' is the zero interval.
  *
  * Requires:
  *
@@ -106,10 +135,10 @@ isc_time_settoepoch(isc_time_t *t);
  *	't' is a valid pointer.
  */
 
-isc_boolean_t
+bool
 isc_time_isepoch(const isc_time_t *t);
 /*
- * Returns ISC_TRUE iff. 't' is the epoch ("time zero").
+ * Returns true iff. 't' is the epoch ("time zero").
  *
  * Requires:
  *
@@ -208,7 +237,7 @@ isc_time_subtract(const isc_time_t *t, const isc_interval_t *i,
  *		The interval is larger than the time since the epoch.
  */
 
-isc_uint64_t
+uint64_t
 isc_time_microdiff(const isc_time_t *t1, const isc_time_t *t2);
 /*
  * Find the difference in milliseconds between time t1 and time t2.
@@ -232,7 +261,7 @@ isc_time_parsehttptimestamp(char *input, isc_time_t *t);
  *\li      'buf' and 't' are not NULL.
  */
 
-isc_uint32_t
+uint32_t
 isc_time_nanoseconds(const isc_time_t *t);
 /*
  * Return the number of nanoseconds stored in a time structure.
@@ -315,7 +344,7 @@ isc_time_formatISO8601ms(const isc_time_t *t, char *buf, unsigned int len);
  *
  */
 
-isc_uint32_t
+uint32_t
 isc_time_seconds(const isc_time_t *t);
 /*%<
  * Return the number of seconds since the epoch stored in a time structure.
